@@ -20,8 +20,8 @@ InviteDialog::InviteDialog(QWidget* parent)
 {
     setAttribute(Qt::WA_DeleteOnClose);
     setWindowTitle(i18n("Channel Invites"));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
+    auto *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    auto *mainLayout = new QVBoxLayout;
     setLayout(mainLayout);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
@@ -29,7 +29,7 @@ InviteDialog::InviteDialog(QWidget* parent)
     connect(buttonBox, &QDialogButtonBox::accepted, this, &InviteDialog::slotOk);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &InviteDialog::reject);
 
-    QWidget* mainWidget = new QWidget(this);
+    auto* mainWidget = new QWidget(this);
     mainLayout->addWidget(mainWidget);
     mainLayout->addWidget(buttonBox);
     setupUi(mainWidget);
@@ -54,7 +54,7 @@ void InviteDialog::slotOk()
     QString channels = m_channelModel->selectedChannels();
 
     if(!channels.isEmpty())
-        emit joinChannelsRequested(channels);
+        Q_EMIT joinChannelsRequested(channels);
     KConfigGroup::WriteConfigFlags flags = KConfig::Persistent;
     KConfigGroup cg(KSharedConfig::openConfig().data(), "Notification Messages");
     cg.writeEntry("Invitation", m_joinPreferences->currentIndex(), flags);
@@ -200,9 +200,9 @@ bool InviteChannelListModel::setData(const QModelIndex& index, const QVariant& v
 
     QString channel = m_channelMap.values().at(index.row()).channel;
     m_channelMap[channel].checkState = (value.toBool() ? Qt::Checked : Qt::Unchecked);
-    emit dataChanged(index, index);
+    Q_EMIT dataChanged(index, index);
 
     return true;
 }
 
-
+#include "moc_invitedialog.cpp"
